@@ -26,7 +26,6 @@
 #include "pango-fontmap.h"
 #include "pangocoretext-private.h"
 #include "pango-impl-utils.h"
-#include "modules.h"
 
 #include <Carbon/Carbon.h>
 
@@ -115,13 +114,14 @@ const float ct_weight_min = -1.00f;
 const float ct_weight_max = 1.00f;
 
 static const PangoCTWeight ct_weight_limits[] = {
-    { -0.70, PANGO_WEIGHT_THIN},
-    { -0.50, PANGO_WEIGHT_ULTRALIGHT },
-    { -0.35, PANGO_WEIGHT_LIGHT },
+    { -0.00, PANGO_WEIGHT_THIN },
+    { -0.75, PANGO_WEIGHT_ULTRALIGHT },
+    { -0.50, PANGO_WEIGHT_LIGHT },
+    { -0.25, PANGO_WEIGHT_SEMILIGHT },
     { -0.10, PANGO_WEIGHT_BOOK },
-    {  0.10, PANGO_WEIGHT_NORMAL },
-    {  0.24, PANGO_WEIGHT_MEDIUM },
-    {  0.36, PANGO_WEIGHT_SEMIBOLD },
+    {  0.00, PANGO_WEIGHT_NORMAL },
+    {  0.10, PANGO_WEIGHT_MEDIUM },
+    {  0.25, PANGO_WEIGHT_SEMIBOLD },
     {  0.50, PANGO_WEIGHT_BOLD },
     {  0.75, PANGO_WEIGHT_ULTRABOLD },
     {  1.00, PANGO_WEIGHT_HEAVY }
@@ -291,13 +291,13 @@ ct_font_descriptor_get_weight (CTFontDescriptorRef desc)
   CFDictionaryRef dict;
   CFNumberRef cf_number;
   CGFloat value;
-  PangoWeight weight;
+  PangoWeight weight = PANGO_WEIGHT_NORMAL;
 
   dict = CTFontDescriptorCopyAttribute (desc, kCTFontTraitsAttribute);
   cf_number = (CFNumberRef)CFDictionaryGetValue (dict,
                                                  kCTFontWeightTrait);
 
-  if (CFNumberGetValue (cf_number, kCFNumberCGFloatType, &value))
+  if (cf_number != NULL && CFNumberGetValue (cf_number, kCFNumberCGFloatType, &value))
     {
       if (value < ct_weight_min || value > ct_weight_max)
 	{
@@ -310,6 +310,7 @@ ct_font_descriptor_get_weight (CTFontDescriptorRef desc)
 	  for (i = 0; i < G_N_ELEMENTS(ct_weight_limits); i++)
 	    if (value < ct_weight_limits[i].bound)
 	      {
+	        /* TODO interpolate weight. */
                 weight = ct_weight_limits[i].weight;
                 break;
 	      }
@@ -411,6 +412,9 @@ _pango_core_text_font_description_from_ct_font_descriptor (CTFontDescriptorRef d
   else
     pango_font_description_set_style (font_desc, PANGO_STYLE_NORMAL);
 
+  if ((font_traits & kCTFontCondensedTrait) == kCTFontCondensedTrait)
+    pango_font_description_set_stretch (font_desc, PANGO_STRETCH_CONDENSED);
+
   if (ct_font_descriptor_is_small_caps (desc))
     pango_font_description_set_variant (font_desc, PANGO_VARIANT_SMALL_CAPS);
   else
@@ -713,7 +717,6 @@ static void
 pango_core_text_family_class_init (PangoCoreTextFamilyClass *klass)
 {
   GObjectClass *object_class = (GObjectClass *)klass;
-  int i;
   PangoFontFamilyClass *pfclass = PANGO_FONT_FAMILY_CLASS(klass);
 
   object_class->finalize = pango_core_text_family_finalize;
@@ -721,9 +724,6 @@ pango_core_text_family_class_init (PangoCoreTextFamilyClass *klass)
   pfclass->list_faces = pango_core_text_family_list_faces;
   pfclass->get_name = pango_core_text_family_get_name;
   pfclass->is_monospace = pango_core_text_family_is_monospace;
-
-  for (i = 0; _pango_included_core_text_modules[i].list; i++)
-    pango_module_register (&_pango_included_core_text_modules[i]);
 }
 
 static void
@@ -1522,10 +1522,12 @@ G_DEFINE_TYPE (PangoCoreTextFontset,
                pango_core_text_fontset,
                PANGO_TYPE_FONTSET);
 
+#if !defined(MAC_OS_X_VERSION_10_8) || MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_8
 /* This symbol does exist in the CoreText library shipped with Snow
  * Leopard and Lion, however, it is not found in the public header files.
  */
 CFArrayRef CTFontCopyDefaultCascadeList (CTFontRef font_ref);
+#endif
 
 static PangoCoreTextFontset *
 pango_core_text_fontset_new (PangoCoreTextFontsetKey    *key,
@@ -1589,7 +1591,28 @@ pango_core_text_fontset_new (PangoCoreTextFontsetKey    *key,
   fontset->coverages = g_ptr_array_new ();
 
   /* Add the cascade list for this language */
+#if defined(MAC_OS_X_VERSION_10_8) && MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_8
+    {
+      CFArrayRef language_pref_list;
+      CFStringRef languages[1];
+
+      languages[0] = CFStringCreateWithCString (NULL,
+                                                pango_language_to_string (key->language),
+                                                kCFStringEncodingASCII);
+      language_pref_list = CFArrayCreate (kCFAllocatorDefault,
+                                          (const void **) languages,
+                                          1,
+                                          &kCFTypeArrayCallBacks);
+      fontset->cascade_list = CTFontCopyDefaultCascadeListForLanguages (pango_core_text_font_get_ctfont (best_font), language_pref_list);
+      CFRelease (languages[0]);
+      CFRelease (language_pref_list);
+    }
+#else
+  /* There is unfortunately no public API to retrieve the cascade list
+   * on Mac OS X < 10.8, so we use the following undocumented public function.
+   */
   fontset->cascade_list = CTFontCopyDefaultCascadeList (pango_core_text_font_get_ctfont (best_font));
+#endif
 
   /* length of cascade list + 1 for the "real" font at the front */
   g_ptr_array_set_size (fontset->fonts, CFArrayGetCount (fontset->cascade_list) + 1);
