@@ -34,7 +34,6 @@
 #include "pango-fontmap.h"
 #include "pango-impl-utils.h"
 #include "pangowin32-private.h"
-#include "modules.h"
 
 typedef struct _PangoWin32Family PangoWin32Family;
 typedef PangoFontFamilyClass PangoWin32FamilyClass;
@@ -493,48 +492,9 @@ read_builtin_aliases (GHashTable *ht_aliases)
 #endif
 
 
-static void
-read_alias_file (const char *filename, GHashTable *ht_aliases)
-{
-  FILE *file;
-
-  GString *line_buffer;
-  char *errstring = NULL;
-  int line = 0;
-
-  file = g_fopen (filename, "r");
-  if (!file)
-    return;
-
-  line_buffer = g_string_new (NULL);
-
-  while (pango_read_line (file, line_buffer) &&
-         errstring == NULL)
-    {
-      line++;
-      handle_alias_line (line_buffer, &errstring, ht_aliases);
-    }
-
-  if (errstring == NULL && ferror (file))
-    errstring = g_strdup (g_strerror(errno));
-
-  if (errstring)
-    {
-      g_warning ("error reading alias file: %s:%d: %s\n", filename, line, errstring);
-      g_free (errstring);
-    }
-
-  g_string_free (line_buffer, TRUE);
-
-  fclose (file);
-}
-
 static GHashTable *
 load_aliases (void)
 {
-  char *filename;
-  const char *home;
-
   GHashTable *ht_aliases = g_hash_table_new_full ((GHashFunc)alias_hash,
                                                   (GEqualFunc)alias_equal,
                                                   (GDestroyNotify)alias_free,
@@ -544,21 +504,6 @@ load_aliases (void)
   read_builtin_aliases (ht_aliases);
 #endif
 
-  filename = g_strconcat (pango_get_sysconf_subdirectory (),
-                          G_DIR_SEPARATOR_S "pango.aliases",
-                          NULL);
-  read_alias_file (filename, ht_aliases);
-  g_free (filename);
-
-  home = g_get_home_dir ();
-  if (home && *home)
-    {
-      filename = g_strconcat (home,
-                              G_DIR_SEPARATOR_S ".pango.aliases",
-                              NULL);
-      read_alias_file (filename, ht_aliases);
-      g_free (filename);
-    }
   return ht_aliases;
 }
 
@@ -721,7 +666,6 @@ _pango_win32_font_map_class_init (PangoWin32FontMapClass *class)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (class);
   PangoFontMapClass *fontmap_class = PANGO_FONT_MAP_CLASS (class);
-  int i;
 
   class->find_font = pango_win32_font_map_real_find_font;
   object_class->finalize = pango_win32_font_map_finalize;
@@ -732,9 +676,6 @@ _pango_win32_font_map_class_init (PangoWin32FontMapClass *class)
   fontmap_class->shape_engine_type = PANGO_RENDER_TYPE_WIN32;
 
   pango_win32_get_dc ();
-
-  for (i = 0; _pango_included_win32_modules[i].list; i++)
-    pango_module_register (&_pango_included_win32_modules[i]);
 }
 
 /**
